/** ===========================================================
 *
 * This file is a part of digiKam project
 * <a href="http://www.digikam.org">http://www.digikam.org</a>
 *
 * @date   2007-02-12
 * @brief  libraw program interface for KDE
 *
 * @author Copyright (C) 2007-2013 by Gilles Caulier
 *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef KDCRAW_VERSION_H
#define KDCRAW_VERSION_H

// Before changing the line below, make sure that FindKdcraw.cmake can still parse it
static const char kdcraw_version[] = "2.4.2";

#define KDCRAW_VERSION 0x020402

#endif // KDCRAW_VERSION_H
